%global _description\
Schemas for messages sent by Copr project, as described on \
fedora-messaging documentation page \
https://fedora-messaging.readthedocs.io/en/latest/messages.html#schema \
\
Package also provides several convenience methods for working with \
copr messages.

Name:       copr-messaging
Version:    1.0
Release:    1.20241120181147788814.main.3.g4313913f9%{?dist}
Summary:    Abstraction for Copr messaging listeners/publishers

License:    GPL-2.0-or-later
URL:        https://github.com/fedora-copr/copr

# Source is created by:
# git clone %%url && cd copr
# tito build --tgz --tag %%name-%%version-%%release
Source0:    copr-messaging-git-0.e20620e.tar.gz

BuildArch:  noarch

Requires:      wget


BuildRequires: asciidoc
BuildRequires: libxslt
BuildRequires: util-linux

BuildRequires: python3-copr-common
BuildRequires: python3-devel
BuildRequires: python3-fedora-messaging
BuildRequires: python3-pytest
BuildRequires: python3-setuptools
BuildRequires: python3-sphinx

%description %_description


%package -n python3-%name
Summary: %summary
Provides: %name = %version
%{?python_provide:%python_provide python3-%{name}}

Requires: python3-copr-common
Requires: python3-fedora-messaging

%description -n python3-%name %_description

%package -n python3-%name-doc
Summary: Code documentation for copr messaging

%description -n python3-%name-doc %_description

This package contains documentation for copr-messaging.


%prep
%setup -q -n copr-messaging-git-0.e20620e


%build
%py3_build
PYTHONPATH=${PWD} sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}


%install
%py3_install


%check
./run_tests.sh -vv


%files -n python3-%name
%license LICENSE
%doc README.md
%python3_sitelib/copr_messaging
%python3_sitelib/copr_messaging*egg-info

%files -n python3-%name-doc
%license LICENSE
%doc html


%changelog
* Wed Nov 20 2024 Packit <hello@packit.dev> - 1.0-1.20241120181147788814.main.3.g4313913f9
- beakertests: move PyPI tests into one file (Pavel Raiskup)
- mics: copr_new_packages add limit option and progressbar (Jiri Kyjovsky)
- misc: copr_new_packages, drop requests to koji api, use repoquery (Jiri Kyjovsky)
- Automatic commit of package [copr-rpmbuild] release [1.2-1]. (Pavel Raiskup)
- docker: point PULP_CONTENT_URL to a local container (Jakub Kadlcik)
- backend: copr-backend-resultdir-cleaner logs into config["log_dir"] (Pavel Raiskup)
- backend: copr-backend-resultdir-cleaner to skip module dirs (Pavel Raiskup)
- backend: manpage for copr-backend-resultdir-cleaner && logger fix (Pavel Raiskup)
- doc: mention powerful builders disk space and admin how to (Jakub Kadlcik)
- Change the pyp2spec invocation (Karolina Surma)
- backend: allow using crt+key pair for Pulp authentication (Jakub Kadlcik)
- Automatic commit of package [copr-backend] release [2.1-1]. (Jakub Kadlcik)
- Automatic commit of package [copr-rpmbuild] release [1.1-1]. (Jakub Kadlcik)
- backend: show what command is being run on the builder (Jakub Kadlcik)
- rpmbuild: log even information about success (Jakub Kadlcik)
- rpmbuild: make_srpmbuild, set recursive safe.directory (Jiri Kyjovsky)
- rpmbuild: basic sanity check for rhsm (Pavel Raiskup)
- frontend: support build-time dependencies from other storages (Jakub Kadlcik)
- frontend: move repo functions to a separate file (Jakub Kadlcik)
- builds_initiated_via_hook always passed as a list & doc string update (Jait Jacob)
- custom webhook handler now adds webhook history record (Jait Jacob)
- rpmbuild, frontend: activate Red Hat subscription on demand (Jakub Kadlcik)
- pylint: fix old import errors that appear as new (Pavel Raiskup)
- python, cli: drop six dependency (Pavel Raiskup)
- rpmbuild: drop six usage (this is a Python 3 only package) (Pavel Raiskup)
- rpmbuild: add tooling for "safer" RH subscription (Pavel Raiskup)
- backend: fix copr-backend-unknown-resalloc-tickets (Pavel Raiskup)
- frontend: avoid a duplicated "exists" check (Pavel Raiskup)
- enhance: dnf.conf(5) docs link (Malix)
- doc: release-notes 2024-10-03 (Jiri Kyjovsky)
- frontend: check whether copr exists (Jait Jacob)
- distgit: depend on python3-rpkg >= 1.67-4 (Jakub Kadlcik)
- tito: drop support for el7 (Jiri Kyjovsky)
- backend: unknown-resalloc-tickets: check tickets taken first (Pavel Raiskup)
- Automatic commit of package [copr-frontend] release [2.1-1]. (Pavel Raiskup)
- frontend: no `app.log` but `app.logger` (Pavel Raiskup)
- Automatic commit of package [copr-backend] release [2.0-1]. (Jiri Kyjovsky)
- Automatic commit of package [copr-cli] release [2.0-1]. (Jiri Kyjovsky)
- Automatic commit of package [copr-dist-git] release [1.0-1]. (Jiri Kyjovsky)
- Automatic commit of package [copr-frontend] release [2.0-1]. (Jiri Kyjovsky)
- Automatic commit of package [copr-keygen] release [2.0-1]. (Jiri Kyjovsky)

* Wed Oct 02 2024 Jiri Kyjovsky <j1.kyjovsky@gmail.com> 1.0-1
- Set chroot message severity to DEBUG
- One-line descriptions should be the summary

* Fri Mar 01 2024 Pavel Raiskup <praiskup@redhat.com> 0.11-1
- handle namespaced usernames
- set the agent_name and usernames properties

* Mon May 22 2023 Jakub Kadlcik <frostyx@email.cz> 0.10-1
- Derive all message classes from _CoprMessage

* Wed Mar 22 2023 Jiri Kyjovsky <j1.kyjovsky@gmail.com> 0.9-1
- Add app_name property to _CoprMessage base class
* Tue Jan 24 2023 Jakub Kadlcik <frostyx@email.cz> 0.8-1
- Use SPDX license

* Sat Nov 26 2022 Jakub Kadlcik <frostyx@email.cz> 0.7-1
- move to GitHub home page
- sync tooling with other sub-projects

* Tue Jun 21 2022 Jakub Kadlcik <frostyx@email.cz> 0.6-1
- Adapt to the changed stomppy API

* Mon Nov 09 2020 Jakub Kadlcik <frostyx@email.cz> 0.5-1
- explicitely requires python3-setuptools
- all: run pytest with -vv in package build
- pylint: sync all the pylintrc files
- pylint: run pylint in all run*tests.sh files

* Thu Oct 03 2019 Pavel Raiskup <praiskup@redhat.com> 0.4-1
- rename 'stomp_consumer' module to 'stomp'
- fix macros in comments

* Thu Jul 25 2019 Pavel Raiskup <praiskup@redhat.com> 0.3-1
- mention how to create Source0 tarball

* Wed Jul 24 2019 Pavel Raiskup <praiskup@redhat.com> 0.2-1
- apply review fixes (by Silvie)

* Wed Jul 17 2019 Pavel Raiskup <praiskup@redhat.com> 0.1-1
- copr_messaging: new package for working with copr messages
